@@ -30,6 +30,7 @@ class ThermoBeaconDevice:
 DEVICE_TYPES = {
     0x10: ThermoBeaconDevice("16", "Lanyard/mini hygrometer"),
     0x11: ThermoBeaconDevice("17", "Smart hygrometer"),
+    0x14: ThermoBeaconDevice("20", "Smart hygrometer"),
     0x15: ThermoBeaconDevice("21", "Smart hygrometer"),
     0x18: ThermoBeaconDevice("24", "Smart hygrometer"),
     0x1B: ThermoBeaconDevice("27", "Smart hygrometer"),
@@ -68,14 +69,10 @@ class ThermoBeaconBluetoothDeviceData(BluetoothData):
         self.set_title(f"{name} {short_address(service_info.address)}")
         self.set_device_name(f"{name} {short_address(service_info.address)}")
         self.set_device_manufacturer("ThermoBeacon")
-        self._process_update(data)
-
-    def _process_update(self, data: bytes) -> None:
-        """Update from BLE advertisement data."""
         _LOGGER.debug("Parsing ThermoBeacon BLE advertisement data: %s", data)
-        if len(data) != 20:
+        if data[2] != 0x00:
+            # Not a data packet
             return
-
         button_pushed = data[3] & 0x80
         xvalue = data[10:16]
 
